==> uknc-everywhere-1.0.tar.bz2: uknc-everywhere-1.0/MainWindow.cpp <==
#include <QFileDialog>
#include "MainWindow.h"

MainWindow::MainWindow() {
  setupUi( this );

  QActionGroup *screenModeGroup = new QActionGroup( this );
  screenModeGroup->addAction( actionRGBScreen );
  screenModeGroup->addAction( actionGRBScreen );
  screenModeGroup->addAction( actionGrayscaleScreen );

  QActionGroup *heightModeGroup = new QActionGroup( this );
  heightModeGroup->addAction( actionNormalHeight );
  heightModeGroup->addAction( actionDoubleHeight );

  connect( actionLoadState, SIGNAL(triggered()), SLOT(doFileLoadState()) );
  connect( actionSaveState, SIGNAL(triggered()), SLOT(doFileSaveState()) );
  connect( actionScreenshot, SIGNAL(triggered()), SLOT(doFileScreenshot()) );
  connect( actionExit, SIGNAL(triggered()), SLOT(hide()) );

  connect( actionKeyboard, SIGNAL(triggered(bool)), SLOT(doViewKeyboard(bool)) );
  connect( actionRGBScreen, SIGNAL(triggered()), SLOT(doViewScreenRGB()) );
  connect( actionGRBScreen, SIGNAL(triggered()), SLOT(doViewScreenGRB()) );
  connect( actionGrayscaleScreen, SIGNAL(triggered()), SLOT(doViewScreenGray()) );
  connect( actionNormalHeight, SIGNAL(triggered()), SLOT(doViewHeightNormal()) );
  connect( actionDoubleHeight, SIGNAL(triggered()), SLOT(doViewHeightDouble()) );

  connect( actionRun, SIGNAL(triggered()), SLOT(doEmulatorRun()) );
  connect( actionAutostart, SIGNAL(triggered(bool)), SLOT(doEmulatorAutostart(bool)) );
  connect( actionReset, SIGNAL(triggered()), SLOT(doEmulatorReset()) );
  connect( actionFloppyMZ0, SIGNAL(triggered()), SLOT(doEmulatorFloppy0()) );
  connect( actionFloppyMZ1, SIGNAL(triggered()), SLOT(doEmulatorFloppy1()) );
  connect( actionFloppyMZ2, SIGNAL(triggered()), SLOT(doEmulatorFloppy2()) );
  connect( actionFloppyMZ3, SIGNAL(triggered()), SLOT(doEmulatorFloppy3()) );
  connect( actionCartridge1, SIGNAL(triggered()), SLOT(doEmulatorCartridge1()) );
  connect( actionCartridge2, SIGNAL(triggered()), SLOT(doEmulatorCartridge2()) );

  connect( actionAbout, SIGNAL(triggered()), SLOT(showAboutDlg()) );

  cw = new CentralWidget( this );
  setCentralWidget( cw );

  restoreSettings();

  if ( !Settings_GetKeyboard() ) {
	cw->keyboardView->hide();
	adjustLayout();
  }

  resize( cw->width(),
          menuBar()->height() + cw->height() + statusBar()->height() );

  screenView()->setFocus();
  show();

  updateMenu();
}

void MainWindow::restoreSettings()
{
    TCHAR buf[PATH_MAX];

    // Reattach floppy images
    for (int slot = 0; slot < 4; slot++)    
    {
        buf[0] = '\0'; 
        Settings_GetFloppyFilePath(slot, buf);
        if (strlen(buf) > 0)
        {
            if (! g_pBoard->AttachFloppyImage(slot, buf))
                Settings_SetFloppyFilePath(slot, NULL);
        }
    }

    // Reattach cartridge images
    for (int slot = 0; slot < 2; slot++)
    {
        buf[0] = '\0';
        Settings_GetCartridgeFilePath(slot, buf);
        if (strlen(buf) > 0)
        {
            Emulator_LoadROMCartridge(slot, buf);
            //TODO: If failed to load Then
            //    Settings_SetCartridgeFilePath(slot, NULL);
        }
    }

    // Restore ScreenViewMode
    int mode = Settings_GetScreenViewMode();
    if (mode <= 0 || mode > 3) mode = RGBScreen;
    screenView()->setMode((ScreenViewMode) mode);


    // Restore ScreenHeightMode
    int heightMode = Settings_GetScreenHeightMode();
    if (heightMode < 1) heightMode = 1;
    if (heightMode > 2) heightMode = 2;
    screenView()->setHeightMode(heightMode);
}

void MainWindow::adjustLayout() {
  cw->adjustLayout();

  resize( cw->width(),
          menuBar()->height() + cw->height() + statusBar()->height() );
}

void MainWindow::doFileLoadState() {
  QString filename = QFileDialog::getOpenFileName( 0,
	"Open state image to load",
	QString(),
	"UKNC state images (*.uknc);;All Files (*.*)" );
  if ( filename.isEmpty() ) return;

  QByteArray lname = filename.toLocal8Bit();
  Emulator_LoadImage( lname.data() );
}

void MainWindow::doFileSaveState() {
  QString filename = QFileDialog::getSaveFileName( 0,
	"Save state image as",
	QString(),
	"UKNC state images (*.uknc);;All Files (*.*)" );
  if ( filename.isEmpty() ) return;

  QByteArray lname = filename.toLocal8Bit();
  Emulator_SaveImage( lname.data() );
}

void MainWindow::doFileScreenshot() {
  QString filename = QFileDialog::getSaveFileName( 0,
	"Save screenshot as",
	QString(),
	"Bitmaps (*.bmp);;All Files (*.*)" );
  if ( filename.isEmpty() ) return;

  screenView()->saveScreenshot( filename );
}

void MainWindow::doEmulatorFloppy( int slot ) {
  if ( g_pBoard->IsFloppyImageAttached( slot ) ) {
	Settings_SetFloppyFilePath( slot, NULL );
	g_pBoard->DetachFloppyImage( slot );
  }
  else {
	QString filename = QFileDialog::getOpenFileName( 0,
		"Open floppy image to load",
		QString(),
		"UKNC floppy images (*.dsk *.rtd);;All Files (*.*)" );
	if ( filename.isEmpty() ) goto fail;

	QByteArray lname = filename.toLocal8Bit();
	if ( !g_pBoard->AttachFloppyImage( slot, lname.data() ) ) {
		AlertWarning( "Failed to attach floppy image." );
		goto fail;
	}

	Settings_SetFloppyFilePath( slot, lname.data() );
  }

  return;

fail:
  updateMenu();
}

void MainWindow::doEmulatorCartridge( int slot ) {
  if ( g_pBoard->IsROMCartridgeLoaded( slot ) ) {
	Settings_SetCartridgeFilePath( slot, NULL );
	g_pBoard->UnloadROMCartridge( slot );
  }
  else {
	QString filename = QFileDialog::getOpenFileName( 0,
		"Open ROM cartridge image to load",
		QString(),
		"UKNC ROM cartridge images (*.bin);;All Files (*.*)" );
	if ( filename.isEmpty() ) {
  		updateMenu();
		return;
	}

	QByteArray lname = filename.toLocal8Bit();
	Emulator_LoadROMCartridge( slot, lname.data() );
	Settings_SetCartridgeFilePath( slot, lname.data() );
  }
}

void MainWindow::updateMenu() {
  actionKeyboard->setChecked( cw->keyboardView->isVisible() );
  actionRun->setChecked( g_okEmulatorRunning );
  actionAutostart->setChecked( Settings_GetAutostart() );

  switch ( screenView()->getMode() ) {
  case RGBScreen:  actionRGBScreen->setChecked( true ); break;
  case GRBScreen:  actionGRBScreen->setChecked( true ); break;
  case GrayScreen: actionGrayscaleScreen->setChecked( true ); break;
  }

  switch( screenView()->getHeightMode() ) {
  case 1: actionNormalHeight->setChecked( true ); break;
  case 2: actionDoubleHeight->setChecked( true ); break;
  }

  actionFloppyMZ0->setChecked( g_pBoard->IsFloppyImageAttached(0) );
  actionFloppyMZ1->setChecked( g_pBoard->IsFloppyImageAttached(1) );
  actionFloppyMZ2->setChecked( g_pBoard->IsFloppyImageAttached(2) );
  actionFloppyMZ3->setChecked( g_pBoard->IsFloppyImageAttached(3) );

  actionCartridge1->setChecked( g_pBoard->IsROMCartridgeLoaded(1) );
  actionCartridge2->setChecked( g_pBoard->IsROMCartridgeLoaded(2) );
}

==> uknc-everywhere-1.1.tar.bz2: uknc-everywhere-1.1/MainWindow.cpp <==
#include <QFileDialog>
#include "MainWindow.h"

MainWindow::MainWindow() {
  setupUi( this );

  QActionGroup *screenModeGroup = new QActionGroup( this );
  screenModeGroup->addAction( actionRGBScreen );
  screenModeGroup->addAction( actionGRBScreen );
  screenModeGroup->addAction( actionGrayscaleScreen );

  QActionGroup *heightModeGroup = new QActionGroup( this );
  heightModeGroup->addAction( actionNormalHeight );
  heightModeGroup->addAction( actionDoubleHeight );

  connect( actionLoadState, SIGNAL(triggered()), SLOT(doFileLoadState()) );
  connect( actionSaveState, SIGNAL(triggered()), SLOT(doFileSaveState()) );
  connect( actionScreenshot, SIGNAL(triggered()), SLOT(doFileScreenshot()) );
  connect( actionExit, SIGNAL(triggered()), SLOT(hide()) );

  connect( actionKeyboard, SIGNAL(triggered(bool)), SLOT(doViewKeyboard(bool)) );
  connect( actionRGBScreen, SIGNAL(triggered()), SLOT(doViewScreenRGB()) );
  connect( actionGRBScreen, SIGNAL(triggered()), SLOT(doViewScreenGRB()) );
  connect( actionGrayscaleScreen, SIGNAL(triggered()), SLOT(doViewScreenGray()) );
  connect( actionNormalHeight, SIGNAL(triggered()), SLOT(doViewHeightNormal()) );
  connect( actionDoubleHeight, SIGNAL(triggered()), SLOT(doViewHeightDouble()) );

  connect( actionRun, SIGNAL(triggered()), SLOT(doEmulatorRun()) );
  connect( actionAutostart, SIGNAL(triggered(bool)), SLOT(doEmulatorAutostart(bool)) );
  connect( actionReset, SIGNAL(triggered()), SLOT(doEmulatorReset()) );
  connect( actionFloppyMZ0, SIGNAL(triggered()), SLOT(doEmulatorFloppy0()) );
  connect( actionFloppyMZ1, SIGNAL(triggered()), SLOT(doEmulatorFloppy1()) );
  connect( actionFloppyMZ2, SIGNAL(triggered()), SLOT(doEmulatorFloppy2()) );
  connect( actionFloppyMZ3, SIGNAL(triggered()), SLOT(doEmulatorFloppy3()) );
  connect( actionCartridge1, SIGNAL(triggered()), SLOT(doEmulatorCartridge1()) );
  connect( actionCartridge2, SIGNAL(triggered()), SLOT(doEmulatorCartridge2()) );

  connect( actionAbout, SIGNAL(triggered()), SLOT(showAboutDlg()) );

  cw = new CentralWidget( this );
  setCentralWidget( cw );

  restoreSettings();

  if ( !Settings_GetKeyboard() ) {
	cw->keyboardView->hide();
	adjustLayout();
  }

  resize( cw->width(),
          menuBar()->height() + cw->height() + statusBar()->height() );

  screenView()->setFocus();
  show();

  updateMenu();
}

void MainWindow::restoreSettings()
{
    // Reattach floppy images
    for (int slot = 0; slot < 4; slot++)    
    {
        QString buf = Settings_GetFloppyFilePath(slot);
        if (!buf.isEmpty())
        {
            if (! g_pBoard->AttachFloppyImage(slot, buf))
                Settings_SetFloppyFilePath(slot, QString());
        }
    }

    // Reattach cartridge images
    for (int slot = 0; slot < 2; slot++)
    {
        QString buf = Settings_GetCartridgeFilePath(slot);
        if (!buf.isEmpty())
        {
            Emulator_LoadROMCartridge(slot, buf);
            //TODO: If failed to load Then
            //    Settings_SetCartridgeFilePath(slot, NULL);
        }
    }

    // Restore ScreenViewMode
    int mode = Settings_GetScreenViewMode();
    if (mode <= 0 || mode > 3) mode = RGBScreen;
    screenView()->setMode((ScreenViewMode) mode);


    // Restore ScreenHeightMode
    int heightMode = Settings_GetScreenHeightMode();
    if (heightMode < 1) heightMode = 1;
    if (heightMode > 2) heightMode = 2;
    screenView()->setHeightMode(heightMode);
}

void MainWindow::adjustLayout() {
  cw->adjustLayout();

  resize( cw->width(),
          menuBar()->height() + cw->height() + statusBar()->height() );
}

void MainWindow::doFileLoadState() {
  QString filename = QFileDialog::getOpenFileName( 0,
	"Open state image to load",
	QString(),
	"UKNC state images (*.uknc);;All Files (*.*)" );

  if ( !filename.isEmpty() )
	Emulator_LoadImage( filename );
}

void MainWindow::doFileSaveState() {
  QString filename = QFileDialog::getSaveFileName( 0,
	"Save state image as",
	QString(),
	"UKNC state images (*.uknc);;All Files (*.*)" );

  if ( !filename.isEmpty() )
	Emulator_SaveImage( filename );
}

void MainWindow::doFileScreenshot() {
  QString filename = QFileDialog::getSaveFileName( 0,
	"Save screenshot as",
	QString(),
	"Bitmaps (*.bmp);;All Files (*.*)" );
  if ( filename.isEmpty() ) return;

  screenView()->saveScreenshot( filename );
}

void MainWindow::doEmulatorFloppy( int slot ) {
  if ( g_pBoard->IsFloppyImageAttached( slot ) ) {
	Settings_SetFloppyFilePath( slot, QString() );
	g_pBoard->DetachFloppyImage( slot );
  }
  else {
	QString filename = QFileDialog::getOpenFileName( 0,
		"Open floppy image to load",
		QString(),
		"UKNC floppy images (*.dsk *.rtd);;All Files (*.*)" );
	if ( filename.isEmpty() ) goto fail;

	if ( !g_pBoard->AttachFloppyImage( slot, filename ) ) {
		AlertWarning( _T("Failed to attach floppy image.") );
		goto fail;
	}

	Settings_SetFloppyFilePath( slot, filename );
  }

  return;

fail:
  updateMenu();
}

void MainWindow::doEmulatorCartridge( int slot ) {
  if ( g_pBoard->IsROMCartridgeLoaded( slot ) ) {
	Settings_SetCartridgeFilePath( slot, QString() );
	g_pBoard->UnloadROMCartridge( slot );
  }
  else {
	QString filename = QFileDialog::getOpenFileName( 0,
		"Open ROM cartridge image to load",
		QString(),
		"UKNC ROM cartridge images (*.bin);;All Files (*.*)" );
	if ( filename.isEmpty() ) {
  		updateMenu();
		return;
	}

	Emulator_LoadROMCartridge( slot, filename );
	Settings_SetCartridgeFilePath( slot, filename );
  }
}

void MainWindow::updateMenu() {
  actionKeyboard->setChecked( cw->keyboardView->isVisible() );
  actionRun->setChecked( g_okEmulatorRunning );
  actionAutostart->setChecked( Settings_GetAutostart() );

  switch ( screenView()->getMode() ) {
  case RGBScreen:  actionRGBScreen->setChecked( true ); break;
  case GRBScreen:  actionGRBScreen->setChecked( true ); break;
  case GrayScreen: actionGrayscaleScreen->setChecked( true ); break;
  }

  switch( screenView()->getHeightMode() ) {
  case 1: actionNormalHeight->setChecked( true ); break;
  case 2: actionDoubleHeight->setChecked( true ); break;
  }

  actionFloppyMZ0->setChecked( g_pBoard->IsFloppyImageAttached(0) );
  actionFloppyMZ1->setChecked( g_pBoard->IsFloppyImageAttached(1) );
  actionFloppyMZ2->setChecked( g_pBoard->IsFloppyImageAttached(2) );
  actionFloppyMZ3->setChecked( g_pBoard->IsFloppyImageAttached(3) );

  actionCartridge1->setChecked( g_pBoard->IsROMCartridgeLoaded(1) );
  actionCartridge2->setChecked( g_pBoard->IsROMCartridgeLoaded(2) );
}
